# Authors:
#   Jason Gerard DeRose <jderose@novacut.com>
#
# dmedia: distributed media library
# Copyright (C) 2010 Jason Gerard DeRose <jderose@novacut.com>
#
# This file is part of `dmedia`.
#
# `dmedia` is free software: you can redistribute it and/or modify it under the
# terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# `dmedia` is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with `dmedia`.  If not, see <http://www.gnu.org/licenses/>.

"""
Unit tests for `dmedia` package.
"""

from unittest import TestCase
import os
from os import path
import logging

from .base import TempHome

import dmedia


class TestFunctions(TestCase):
    def test_configure_logging(self):
        tmp = TempHome()
        cache = tmp.join('.cache', 'dmedia')
        self.assertFalse(path.isdir(cache))
        log = dmedia.configure_logging()
        self.assertIsInstance(log, logging.RootLogger)
        self.assertTrue(path.isdir(cache))
        self.assertEqual(os.listdir(cache), ['setup.py.log'])
        self.assertTrue(path.isfile(path.join(cache, 'setup.py.log')))
 
    def test_get_dmedia_dir(self):
        tmp = TempHome()
        d = dmedia.get_dmedia_dir()
        self.assertEqual(d, tmp.join('.local', 'share', 'dmedia'))
        self.assertTrue(path.isdir(d))
        self.assertEqual(os.listdir(d), [])
